# Introduction

The debootstrap tool can be used to install
a basic copy of a Debian derivative into a folder.

This guide explains how to install a full Kubuntu system with debootstrap.
However, any Ubuntu flavour can be installed this way.

# Procedure

## Basic Minimal Installation

	debootstrap --variant=minbase wily /target http://ch.archive.ubuntu.com/ubuntu

The subsequent commands are all executed inside a
[chroot](Chroot.md) environment.

## Basic Configuration

### Set language

	locale-gen en_US.UTF-8
	update-locale LANG=en_US.UTF-8

### Set timezone

	dpkg-reconfigure tzdata

### Basic configuration

Do not forget to edit `fstab`, `hostname`, and `hosts` in /etc.

An example fstab might look like:

	LABEL=System	/	ext4	errors=remount-ro,noatime,discard	0 1

Note: `discard` is useful for SSD disks.

### Optionally, configure keyboard

	dpkg-reconfigure keyboard-configuration

### Optionally, configure APT

	# /etc/apt/apt.conf.d/99recommends
	APT::AutoRemove::RecommendsImportant
	APT::Install-Recommends

## Ubuntu Installation

### Install Ubuntu minimal

	apt-get install ubuntu-minimal

ubuntu-minimal contains useful packages
which would have to be installed manually in Debian.

These include: `cron logrotate nano netbase net-tools isc-dhcp-client sudo rsyslog`

### Add a regular user

	adduser user

In Ubuntu, the default secondary user groups are:

	adm cdrom sudo dip plugdev lpadmin sambashare

### Install kernel and bootloader

To install a bootable system, the kernel and a bootloader
have to be installed.

The following command installs Grub for EFI with Secure Boot enabled:

	apt-get install linux-generic grub-efi-amd64-signed shim-signed

For BIOS, `grub-pc` has to be installed.

Alternatively, extlinux can be installed instead of grub.
That section has yet to be written though...

### Install desktop system

At this point, it is necessary to enable the
`universe` repository component.
It is a good time to add some repositories.

#### More software repositories

All Ubuntu repositories are enabled using the following configuration:

	# /etc/apt/sources.list
	deb http://ch.archive.ubuntu.com/ubuntu/ wily main restricted universe multiverse
	deb http://ch.archive.ubuntu.com/ubuntu/ wily-security main restricted universe multiverse
	deb http://ch.archive.ubuntu.com/ubuntu/ wily-updates main restricted universe multiverse
	deb http://archive.canonical.com/ubuntu wily partner

Also refer to the [Ubuntu Help](https://help.ubuntu.com/community/Repositories/Ubuntu)
to find about the different components.

Some PPAs are needed to be sure to get the latest software versions.
First the `add-apt-repository` helper is installed,
and then those repositories are added:

	apt-get install software-properties-common
	apt-mark auto software-properties-common

	add-apt-repository ppa:libreoffice/ppa
	add-apt-repository ppa:rvm/smplayer
	add-apt-repository ppa:qtbittorrent-team/qtbittorrent-stable
	echo deb http://debian-mirrors.sdinet.de/debian-multimedia testing main \
	> /etc/apt/sources.list.d/deb-multimedia.list

#### Install desktop packages

Now do an `apt-get update` and install the desktop system:

	apt-get install --install-recommends ubuntu-standard kubuntu-desktop kubuntu-restricted-extras language-pack-kde-en

Personally, I like to use Chrome and SMPlayer:

	apt-get purge ktorrent dragonplayer firefox
	apt-get install --install-recommends --install-suggests libreoffice-{calc,impress,writer,kde,l10n-de}
	apt-get install smplayer mpv ffmpeg
	wget https://dl.google.com/linux/direct/google-chrome-stable_current_amd64.deb

Sometimes, some packages have to be pulled
from [packages.debian.org](http://packages.debian.org) manually.

## Finished!
