# Introduction

This guide describes how to create a bootable medium
for the following purpose:

* Boot in BIOS (Legacy/CSM) mode
* Boot in UEFI mode using Secure Boot
* Start Ubuntu or a Windows 7, 8, or 10 installation

Set the following variables accordingly:

	FULLDEV=/dev/sdb
	DEV=${FULLDEV}1
	MNT=/mnt

# Preparation

## Partition An Empty Medium

	parted "$FULLDEV"
	mklabel msdos
	mkpart pri fat32 1MiB -1s
	set 1 boot on
	quit
	mkdosfs -F 32 -R 8 "$DEV"

## Create Directory Structure

See below for the config files `syslinux.cfg` and `grub.cfg`

	mount -o shortname=winnt "$DEV" "$MNT"
	mkdir -p "$MNT"/boot/syslinux
	mkdir -p "$MNT"/boot/grub
	mkdir -p "$MNT"/efi/boot
	cp syslinux.cfg "$MNT"/boot/syslinux
	cp grub.cfg "$MNT"/boot/grub

# BIOS

	syslinux -i -d boot/syslinux "$DEV"
	cd /usr/lib/syslinux
	for f in libutil libcom32 menu chain; do cp modules/bios/$f.c32 "$MNT"/boot/syslinux; done
	sh -c "cat mbr/mbr.bin > $FULLDEV"

Note: If a `Boot error` gets reported, try this:

* Try a 3.xx version
* `mkdiskimage -4 $FULLDEV 0 64 32`

# UEFI

	grub-install --target=x86_64-efi --uefi-secure-boot \
		--efi-directory="$MNT" --boot-directory="$MNT"/boot \
		--bootloader-id=boot --no-nvram "$DEV"
	cp /usr/lib/shim/shim.efi.signed "$MNT"/efi/boot/bootx64.efi

Note: Due to [a bug](https://bugs.launchpad.net/ubuntu/+source/grub2/+bug/1450783),
the config file needs to be in efi/ubuntu:

	mkdir -p "$MNT"/efi/ubuntu
	cp -a "$MNT"/efi/boot/grub.cfg "$MNT"/efi/ubuntu

# Copy OS files

## Ubuntu

Execute the following commands in the directory of the mounted ISO:

	rsync -Pa casper preseed "$MNT"/

## Windows

Execute the following commands in the directory of the mounted ISO:

	rsync -Pa sources boot efi "$MNT"/
	rm "$MNT"/sources/ei.cfg  # To enable Edition selection
	cp bootmgr "$MNT"/boot
	7z e -o"$MNT"/efi/microsoft/boot sources/boot.wim 1/Windows/Boot/EFI/bootmgfw.efi

When copying Windows 8, the default bootloader gets replaced. Install Shim again:

	cp /usr/lib/shim/shim.efi.signed "$MNT"/efi/boot/bootx64.efi

# Config Files

## syslinux.cfg

	default menu.c32
	prompt 0

	menu title Select Operating System

	label ubuntu
		menu default
		menu label Start    Ubuntu
		kernel /casper/vmlinuz.efi
		append initrd=/casper/initrd.lz file=/cdrom/preseed/ubuntu.seed boot=casper ignore_uuid maybe-ubiquity quiet splash --

	label win7x64
		menu label Install  Windows
		com32 chain.c32
		append fs ntldr=/boot/bootmgr

# grub.cfg

	insmod efi_gop
	insmod efi_uga
	insmod font

	menuentry "Start    Ubuntu" {
		set gfxmode=auto
		set gfxpayload=keep
		linux	/casper/vmlinuz.efi file=/cdrom/preseed/ubuntu.seed boot=casper ignore_uuid maybe-ubiquity quiet splash --
		initrd	/casper/initrd.lz
	}

	menuentry "Install  Windows" {
		insmod part_gpt
		insmod chain
		set root='(hd0,1)'
		chainloader /efi/microsoft/boot/bootmgfw.efi
	}

	menuentry "UEFI Setup" {
		fwsetup
	}

# Recommended Disk Partitioning for Multiboot Systems

	parted /dev/sda
	mklabel gpt
	mkpart Boot fat32 1MiB 257MiB
	mkpart SysUbuntu ext4 257MiB 12GiB
	mkpart SysWin ntfs 12GiB 52GiB
	mkpart Data ext4 52GiB -1s
	set 1 esp on
