Links
=====

* [OpenSSL usage tips and examples](http://conshell.net/wiki/index.php/OpenSSL_usage_tips_and_examples)
* [Multiple SSL Sites Using SubjectAltName](https://www.linode.com/docs/security/ssl/multiple-ssl-sites-using-subjectaltname)
* [Is TLS fast yet](https://istlsfastyet.com/)
* [Chromium Wiki](http://www.chromium.org/Home/chromium-security/education/tls)
* Also see [Nginx Config Files](../conf/nginx/inc/)



Commands
========

Generate RSA Key
----------------

	openssl genrsa -out example.key 2048

Generate CSR
------------

With *new* key:

	openssl req -new -newkey rsa:2048 -nodes -keyout example.key -out example.csr

With *existing* key:

	openssl req -new -key example.key -out example.csr

Common Name = Host

Generate Self-Signed Certificate
--------------------------------

With *new* key:

	openssl req -new -newkey rsa:2048 -nodes -keyout example.key -x509 -days 730 -out example.crt

With *existing* key:

	openssl req -new -key example.key -x509 -days 730 -out example.crt


Sign CSR by CA with Subject Alternative Names
---------------------------------------------

Like *they* do it for $400.

	openssl x509 -CA CA.crt -CAkey CA.key -extfile example.cnf -days 730 -req -in example.csr -out example.crt

First time, use: `-CAcreateserial`

CA.crt must have (default):

	[ v3_ca ]
	basicConstraints = CA:TRUE

Certificate Extensions in `example.cnf`:

	basicConstraints = CA:FALSE
	subjectAltName = @alt_names
	# keyUsage = nonRepudiation, digitalSignature, keyEncipherment
	# subjectKeyIdentifier = hash
	# authorityKeyIdentifier = keyid,issuer

	[ alt_names ]
	DNS.1 = host1.example.com
	DNS.2 = host2.example.com



Conversions
===========

PEM to other
------------

**DER:** `openssl x509 -outform der -in cert.pem -out cert.der`

**P7B:** `openssl crl2pkcs7 -nocrl -certfile certs.pem -certfile more_certs.pem -out certificates.p7b`

**PFX:** `openssl pkcs12 -export -inkey private.key -in certs.pem -certfile more_certs.pem -out certificates.p7b`

Other to PEM
------------

**DER:** `openssl x509 -inform der -in cert.der -out cert.pem`

**P7B:** `openssl pkcs7 -print_certs -in certs.p7b -out certs.pem`

**PFX:** `openssl pkcs12 -nodes -in certs.pfx -out certs.pem`



Tips
====

* Check site on [SSL Labs](https://www.ssllabs.com/).
* Always use the newest version of OpenSSL
* Disable SSLv\*
* *Forward Secrecy:*
  Enable EECDH or EDH
* To support Internet Explorer on XP,
  enable DES-CBC3-SHA
